/*
 * This file is part of presence  *
 *
 * Copyright  2011 Nokia Corporation and/or its subsidiary(-ies). Allrights reserved.
 *
 * Contact: Alvi Hirvela <Alvie.Hirvela@nokia.com>
 *
 * This software, including documentation, is protected by copyrightcontrolled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others  without the prior written consent of Nokia.
 */
 #ifndef GLOBALPRESENCEINDICATOR_H
#define GLOBALPRESENCEINDICATOR_H


#include <MExport>
#include <QObject>
#include "singletonbase.h"


class M_EXPORT GlobalPresenceIndicator : public QObject, public SingletonBase<GlobalPresenceIndicator>
{
    friend class SingletonBase<GlobalPresenceIndicator>;
    
    Q_OBJECT
    Q_ENUMS(GLOBAL_PRESENCE)

public:

    enum GLOBAL_PRESENCE{
        GLOBAL_PRESENCE_DISCONNECTED = 0,
        GLOBAL_PRESENCE_OFFLINE = 1,
        GLOBAL_PRESENCE_BUSY = 2,
        GLOBAL_PRESENCE_ONLINE = 3
     };

    GlobalPresenceIndicator::GLOBAL_PRESENCE globalPresence();


protected:

    GlobalPresenceIndicator( QObject* parent = 0);


Q_SIGNALS:

    /**
      \brief Signal indicating that a  global presence state took place
      \param newPresence The new presence that is now valid
      \remarks Please note that calling \sa globalPresence() will return the same presence as is provided by this signal
      */
    void globalPresenceChanged( GlobalPresenceIndicator::GLOBAL_PRESENCE newPresence );


    void globalPresenceChanged();

private Q_SLOTS:

    /**
      \brief Update global presence internally and emit if presence changed
      \remarks This function does emit signal indicating that presence changed
      */
    void slotUpdateGlobalPresenceAndSignalStateChange();


private:

    /**
      \brief Update global presence internally and return if presence changed
      \return true - presence was changed
      \return false - presence was kept unchanged

      \remarks This function does not emit any signal indicating presence changes
      */
    bool updateGlobalPresenceInternally();


    /// \brief Holds the current global presence
    GLOBAL_PRESENCE m_currentGlobalPresence;
};


#endif // GLOBALPRESENCEINDICATOR_H
